jaclearn.rl.algo.math
=====================

.. automodule:: jaclearn.rl.algo.math

   
   
   

   
   
   .. rubric:: Classes

   .. autosummary::
      :template: class.rst
   
      LinearValueRegressor
      ObservationNormalizer
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
   
      compute_gae
      discount_cumsum
      discount_return
      normalize_advantage
   
   

   
   
   








.. rubric:: Class LinearValueRegressor
.. autoclass:: LinearValueRegressor
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__


.. rubric:: Class ObservationNormalizer
.. autoclass:: ObservationNormalizer
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__







.. rubric:: Functions

.. autofunction:: compute_gae

.. autofunction:: discount_cumsum

.. autofunction:: discount_return

.. autofunction:: normalize_advantage


